pg.ddx.io  pgsql-performance@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Tom Lane <tgl@sss.pgh.pa.us>
To: Ian Westmacott <ianw@intellivid.com>
Cc: pgsql-performance@postgresql.org
Subject: Re: Why hash join instead of nested loop?
Date: Tue, 09 Aug 2005 10:33:37 -0400
Message-ID: <15881.1123598017@sss.pgh.pa.us> (raw)
In-Reply-To: <1123589756.15206.4.camel@spectre.intellivid.com>
References: <41b0fe890508051135712a086b@mail.gmail.com>
	<001801c59a0a$f4be7480$9a00a8c0@OTTO>
	<41b0fe8905080516164464e04f@mail.gmail.com>
	<15425.1123304631@sss.pgh.pa.us>
	<41b0fe89050808100021a2a4fc@mail.gmail.com>
	<10930.1123549106@sss.pgh.pa.us>
	<1123589756.15206.4.camel@spectre.intellivid.com>

Ian Westmacott <ianw@intellivid.com> writes:
> On Mon, 2005-08-08 at 20:58, Tom Lane wrote:
>> I'd be interested to see results from other people using 7.4.* too.

> 7.4.8:
>  Total runtime: 0.198 ms

> 7.4.2:
>  Total runtime: 0.697 ms

Just to be clear: those are two different machines of different speeds,
right?  I don't believe we put any factor-of-three speedups into 7.4.*
after release ;-)

			regards, tom lane



view thread (18+ messages)  latest in thread

Message-ID: <15881.1123598017@sss.pgh.pa.us>
Permalink:  ../15881.1123598017@sss.pgh.pa.us/
Also on:    postgresql.org/message-id/15881.1123598017@sss.pgh.pa.us

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-performance@postgresql.org
  Cc: tgl@sss.pgh.pa.us, ianw@intellivid.com
  Subject: Re: Why hash join instead of nested loop?
  In-Reply-To: <15881.1123598017@sss.pgh.pa.us>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox